Injection pattern

In this example, a Single HTML source is used for various injections.

- Place "Rilke" in column 1 `<a href="inject-sources.html#pos-1" class="pat-inject">`
- Place "Wilde" in column 2 `<a href="inject-sources.html#pos-2" class="pat-inject">`
- Place "Cocteau" in column 3 `<a href="inject-sources.html#pos-3" class="pat-inject">`
- Place "Cocteau" in column 1, "Rilke" in column 2 and "Wilde" in column 3 `<a href="inject-sources.html" data-pat-inject="#pos-3 #pos-1 &&#pos-1 #pos-2 &&#pos-2 #pos-3" class="pat-inject">`
- Place "Cocteau" in all columns `<a href="inject-sources.html#pos-3" data-pat-inject="source: #pos-3; target: .item article" class="pat-inject">Place "Cocteau" in all columns</a>`
- Autoloads "Wilde" in column 4 after a 2 second delay `<a href="inject-sources.html#pos-2" data-pat-inject="source: #pos-2; target: #pos-4; trigger: autload; delay: 2000" class="pat-inject">Autoloads "Wilde" in column 4 after a 2 second delay</a>`

?

?

?

?